@@ -19,7 +19,7 @@ WCF_ROOT = os.path.abspath(os.path.dirname(__file__))
 sys.path.insert(0, WCF_ROOT)
 import wcf_pb2  # noqa
 
-__version__ = "3.7.0.30.17"
+__version__ = "3.7.0.30.19.2"
 
 
 def _retry():
@@ -57,7 +57,8 @@ class Wcf():
             self.content = msg.content
 
         def __str__(self) -> str:
-            s = f"{self.sender}[{self.roomid}] {self.id}-{self.type}-{self.xml.replace(chr(10), '').replace(chr(9),'')}\n"
+            s = f"{'自己发的:' if self._is_self else ''}"
+            s += f"{self.sender}[{self.roomid}]:{self.id}:{self.type}:{self.xml.replace(chr(10), '').replace(chr(9),'')}\n"
             s += self.content
             return s
 
@@ -382,9 +383,9 @@ class Wcf():
         }
         friends = []
         for cnt in self.get_contacts():
-            if (cnt.wxid.endswith("@chatroom")      # 群聊
-                or cnt.wxid.startswith("gh_")       # 公众号
-                or cnt.wxid in not_friends.keys()   # 其他杂号
+            if (cnt["wxid"].endswith("@chatroom")      # 群聊
+                or cnt["wxid"].startswith("gh_")       # 公众号
+                or cnt["wxid"] in not_friends.keys()   # 其他杂号
                 ):
                 continue
             friends.append(cnt)
